package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.Indexconfig;

/**
 * 主页工作台配置Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface IndexconfigMapper 
{
    /**
     * 查询主页工作台配置
     * 
     * @param id 主页工作台配置主键
     * @return 主页工作台配置
     */
    public Indexconfig selectIndexconfigById(Long id);

    /**
     * 查询主页工作台配置列表
     * 
     * @param indexconfig 主页工作台配置
     * @return 主页工作台配置集合
     */
    public List<Indexconfig> selectIndexconfigList(Indexconfig indexconfig);

    /**
     * 新增主页工作台配置
     * 
     * @param indexconfig 主页工作台配置
     * @return 结果
     */
    public int insertIndexconfig(Indexconfig indexconfig);

    /**
     * 修改主页工作台配置
     * 
     * @param indexconfig 主页工作台配置
     * @return 结果
     */
    public int updateIndexconfig(Indexconfig indexconfig);

    /**
     * 删除主页工作台配置
     * 
     * @param id 主页工作台配置主键
     * @return 结果
     */
    public int deleteIndexconfigById(Long id);

    /**
     * 批量删除主页工作台配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIndexconfigByIds(Long[] ids);

    /**
     * 查询主页工作台配置列表
     *
     * @return 主页工作台配置集合
     */
    public List<Indexconfig> getIndexconfigList(Long indexType);
}
