package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.Indexconfig;
import com.ruoyi.model.service.IIndexconfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 主页工作台配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/indexconfig")
public class IndexconfigController extends BaseController
{
    @Autowired
    private IIndexconfigService indexconfigService;

    /**
     * 查询主页工作台配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:indexconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(Indexconfig indexconfig)
    {
        startPage();
        List<Indexconfig> list = indexconfigService.selectIndexconfigList(indexconfig);
        return getDataTable(list);
    }

    /**
     * 导出主页工作台配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:indexconfig:export')")
    @Log(title = "主页工作台配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Indexconfig indexconfig) throws IOException {
        List<Indexconfig> list = indexconfigService.selectIndexconfigList(indexconfig);
        ExcelUtil<Indexconfig> util = new ExcelUtil<Indexconfig>(Indexconfig.class);
        util.exportExcel(response, list, "主页工作台配置数据");
    }

    /**
     * 获取主页工作台配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:indexconfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(indexconfigService.selectIndexconfigById(id));
    }

    /**
     * 新增主页工作台配置
     */
    @PreAuthorize("@ss.hasPermi('model:indexconfig:add')")
    @Log(title = "主页工作台配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Indexconfig indexconfig)
    {
        return toAjax(indexconfigService.insertIndexconfig(indexconfig));
    }

    /**
     * 修改主页工作台配置
     */
    @PreAuthorize("@ss.hasPermi('model:indexconfig:edit')")
    @Log(title = "主页工作台配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Indexconfig indexconfig)
    {
        return toAjax(indexconfigService.updateIndexconfig(indexconfig));
    }

    /**
     * 删除主页工作台配置
     */
    @PreAuthorize("@ss.hasPermi('model:indexconfig:remove')")
    @Log(title = "主页工作台配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(indexconfigService.deleteIndexconfigByIds(ids));
    }
}
